Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(488)

Unified Diff: sdk/lib/_internal/pub/lib/src/hosted_source.dart

Issue 15347004: Gracefully handle pubspecs with dependencies using unknown sources. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Add tests for unknown sources in lockfiles. Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sdk/lib/_internal/pub/lib/src/git_source.dart ('k') | sdk/lib/_internal/pub/lib/src/lock_file.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sdk/lib/_internal/pub/lib/src/hosted_source.dart
diff --git a/sdk/lib/_internal/pub/lib/src/hosted_source.dart b/sdk/lib/_internal/pub/lib/src/hosted_source.dart
index 17b18399cb209e16c3066aa69418202f37d0c0f0..62503fe1274f6b2d3a1c7f1c28837f512a96310c 100644
--- a/sdk/lib/_internal/pub/lib/src/hosted_source.dart
+++ b/sdk/lib/_internal/pub/lib/src/hosted_source.dart
@@ -48,7 +48,7 @@ class HostedSource extends Source {
/// Downloads and parses the pubspec for a specific version of a package that
/// is available from the site.
- Future<Pubspec> describe(PackageId id) {
+ Future<Pubspec> describeUncached(PackageId id) {
// Request it from the server.
var url = _makeVersionUrl(id, (server, package, version) =>
"$server/packages/$package/versions/$version.yaml");
@@ -191,9 +191,9 @@ class OfflineHostedSource extends HostedSource {
throw new UnsupportedError("Cannot install packages when offline.");
}
- Future<Pubspec> describe(PackageId id) {
+ Future<Pubspec> describeUncached(PackageId id) {
// [getVersions()] will only return packages that are already cached.
// SystemCache should only call [describe()] on a package after it has
// failed to find it in the cache, so this code should not be reached.
throw new UnsupportedError("Cannot describe packages when offline.");
}
@@ -191,9 +191,9 @@ class OfflineHostedSource extends HostedSource {
// [getVersions()] will only return packages that are already cached.
- // SystemCache should only call [describe()] on a package after it has
+ // Source should only call [describeUncached()] on a package after it has
// failed to find it in the cache, so this code should not be reached.
throw new UnsupportedError("Cannot describe packages when offline.");
« no previous file with comments | « sdk/lib/_internal/pub/lib/src/git_source.dart ('k') | sdk/lib/_internal/pub/lib/src/lock_file.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698